package gandi

import (
	"github.com/go-gandi/go-gandi/domain"
	"github.com/go-gandi/go-gandi/email"
	"github.com/go-gandi/go-gandi/livedns"
	"github.com/go-gandi/go-gandi/simplehosting"
)

// Config manages common config for all Gandi API types
type Config struct {
	// SharingID is the Organization ID, available from the Organization API
	SharingID string
	// Debug enables verbose debugging of HTTP calls
	Debug bool
	// DryRun prevents the API from making changes. Only certain API calls support it.
	DryRun bool
}

// NewDomainClient returns a client to the Gandi Domains API
// It expects an API key, available from https://account.gandi.net/en/
func NewDomainClient(apikey string, config Config) *domain.Domain {
	return domain.New(apikey, config.SharingID, config.Debug, config.DryRun)
}

// NewEmailClient returns a client to the Gandi Email API
// It expects an API key, available from https://account.gandi.net/en/
func NewEmailClient(apikey string, config Config) *email.Email {
	return email.New(apikey, config.SharingID, config.Debug, config.DryRun)
}

// NewLiveDNSClient returns a client to the Gandi Domains API
// It expects an API key, available from https://account.gandi.net/en/
func NewLiveDNSClient(apikey string, config Config) *livedns.LiveDNS {
	return livedns.New(apikey, config.SharingID, config.Debug, config.DryRun)
}

// NewSimpleHostingClient returns a client to the Gandi Simple Hosting API
// It expects an API key, available from https://account.gandi.net/en/
func NewSimpleHostingClient(apikey string, config Config) *simplehosting.SimpleHosting {
	return simplehosting.New(apikey, config.SharingID, config.Debug, config.DryRun)
}
